@@ -1,22 +1,11 @@
 from pdfminer.utils import PDFDocEncoding
 from pdfminer.psparser import PSLiteral
-try:
-    from cdecimal import Decimal, ROUND_HALF_UP
-except ImportError:
-    from decimal import Decimal, ROUND_HALF_UP
+from pdfminer.pdftypes import PDFObjRef
+from decimal import Decimal, ROUND_HALF_UP
 import numbers
 from operator import itemgetter
 import itertools
-import six
-
-if six.PY3:
-    from functools import lru_cache as cache
-else:
-    # Python 2 has no lru_cache, so defining as a no-op
-    def cache(**kwargs):
-        def decorator(fn):
-            return fn
-        return decorator
+from functools import lru_cache as cache
 
 DEFAULT_X_TOLERANCE = 3
 DEFAULT_Y_TOLERANCE = 3
@@ -76,7 +65,7 @@ def decode_text(s):
     Adds py3 compatibility to pdfminer's version.
     """
     if type(s) == bytes and s.startswith(b'\xfe\xff'):
-        return six.text_type(s[2:], 'utf-16be', 'ignore')
+        return str(s[2:], 'utf-16be', 'ignore')
     else:
         ords = (ord(c) if type(c) == str else c for c in s)
         return ''.join(PDFDocEncoding[o] for o in ords)
@@ -85,6 +74,23 @@ def decode_psl_list(_list):
     return [ decode_text(value.name) if isinstance(value, PSLiteral) else value
         for value in _list ]
 
+# via pdfminer.pdftypes, altered slightly
+def resolve_all(x):
+    """
+    Recursively resolves the given object and all the internals.
+    """
+    t = type(x)
+    if t == PDFObjRef:
+        return resolve_all(x.resolve())
+    elif t == list:
+        return [ resolve_all(v) for v in x ]
+    elif t == tuple:
+        return tuple(resolve_all(v) for v in x)
+    elif t == dict:
+        return dict((k, resolve_all(v)) for k, v in x.items())
+    else:
+        return x
+
 @cache(maxsize = int(10e4))
 def _decimalize(v, q = None):
     # If already a decimal, just return itself
